const { app, BrowserWindow, ipcMain } = require('electron');
const path = require('node:path');

let mainWindow;
let preloadWindow;

function createPreloadWindow() {
  preloadWindow = new BrowserWindow({
    icon: path.join(__dirname, 'icon/icon_x256.png'),
    width: 400,
    height: 300,
    frame: false,
    transparent: true,
    alwaysOnTop: true,
    webPreferences: {
      nodeIntegration: true,
      contextIsolation: false,
    }
  })
  preloadWindow.loadFile('public/loading.html')
}

function createMainWindow() {
  mainWindow = new BrowserWindow({
    icon: path.join(__dirname, 'icon/icon_x256.png'),
    width: 800,
    height: 600,
    minHeight: 550,
    minWidth: 400,
    webPreferences: {
      preload: path.join(__dirname, 'preload.js'),
      nodeIntegration: true,
      contextIsolation: false,
    }
  })

  mainWindow.setMenu(null) // remove dev tools
  mainWindow.loadFile('public/index.html');
  mainWindow.once('ready-to-show', () => {
    if (preloadWindow) {
      preloadWindow.close();
    }
    mainWindow.show();
  })
}

app.on('ready', () => {
  createPreloadWindow();
})

ipcMain.on('startMainApp', (event) =>
  {
      event.reply('coFound');
      createMainWindow();
      mainWindow.once('ready-to-show', () =>
      {
          mainWindow.show();
          preloadWindow.close();
      });
  });

app.on('window-all-closed', () => {
  if (process.platform !== 'darwin') {
    app.quit();
  }
})

app.on('activate', () => {
  if (BrowserWindow.getAllWindows().length === 0) {
    createMainWindow();
  }
})
